---
title: "Robert Barry's *Music of the Future*"
authors: ["nikomas.md"]
abstract: "An exploration of the entanglement between music and the future"
keywords: ["Music", "Music Philosophy", "Capitalist Realism"]
---


It needn’t be said that thinking about the future of music is not a matter limited to Sun Ra, Simon Reynolds. 100 years ago, there were a lot of books and essays with this title: “The Future of Music” (1).

Robert Barry reminds us that the question of a future music has been consistently on the minds of critics and philosophers for centuries. Some writers, such as Charles Fourier, have even gone so far to envision a kind of music-oriented society, where everything is arranged according to western classical theory, modes and scales of interests and priorities, literally with an opera theatre at the centre of the city. Such wild ideas have been proposed, such as Berlioz’ fantasy society that fundamentally revolves around a yearly operatic production, and such ideas have been experimented with, including the Wagner & Bayreuth festival in Germany where a small bavarian town is overtaken and transformed into some reflection of Berlioz’ ‘euphonia’ (2).

Robert Barry reminds us earlier that prophecy and music go hand in hand, and have done for thousands of years, contending that, in line with Jacques Attali’s ideas, music has always functioned as a kind of heralding of a new society yet to come (3).

Given this suggested relationship between music and the future, anticapitalist connotations seep into the text from an early point, referencing the work of George Bataille who wrote about the inseparability of anticapitalism and the musical future within Fourier’s work. Regarding this discussion, Terry Rilet, the subject of Barry’s first interview, ties these threads together, by stating that any prophetic music, any utopian musical future, is completely prevented by capitalism, and that any meaningful music of the future, or any hope of realising the musical utopianism of Fourier, Bataille, Adorno, or whoever, is only possible without the commercial imperatives of record labels and talent agencies. In a way that is in-keeping with the current critical sociological zeitgeist, much of Barry’s early discussions in the text, and much of the references he is falling back on, seem to be suggesting that 1) there is no future without music, and 2) a musical utopia can only exist with the eradication of copyright, markets, and, in general, capitalism:

“ [Asking Terry Riley] “You’ve been called a ‘visionary’ composer before, so how do you imagine the music of the future?” My question was greeted by a ripple of what I took at the time to be somewhat derisory laughter, both from the stage and from the audience. “You’re trying to put me on the spot!” chuckled Riley uncomfortably. I pictured him secretly signalling to the security guards. “All I can say is,” he finally replied, “that I just hope there is a future”.”

After this point, the author makes like Sun Ra and begins to jump around time and space, landing his spacecraft in 1985, 2014, 2079, 2015, and so on. From here now, Barry dives into the thick of it, and after this point it evolves into a gripping read. Barry takes us through a discussion about John Cage, contrasting the young Cage of 1937 with the older Cage of 1974. In the beginning, Cage desired to control sound, but by the end, this aspiration for future music had become mired in a conservativism; he began to reject human involvement, seeking, as others like Pierre Schaefer and Karlheinz Stockhausen did, a pursuit of “sonic purity”. It has been described as a latent conservatism because it appears to present human involvement as a kind of perversion of natural purity, even seeming akin to manipulating the vinyl record as it spins on the turntable. A future music for this version of Cage, would seemingly result in the absence of music, in a world of people refraining from involvement, all seeking to remain as still as possible, as not to further muddy the already toxic, in their eyes/ears, anthropophonocene that we live in. The other element of interest here, which leads us into our next superstar alien, is that all of these people, Stockhausen and Schaefer, in their pursuit of some white notion of sonic purity, are forced to engage with the machine/ As Barry writes, all of these purists have to make use of often military grade machinery to try and track down the fundamental atoms of sound, no different to how complex military grade machinery became the only hope for knowing the subatomic. Yet, there were other ways to conceptualise the machine, and indeed the history of electronic music, regardless of any origins, was fundamentally championed by black radical musicians. No experimental laboratory in Berlin can compare to the impact black musicians had on the direction of future music, especially in the case of Techno, Hip-Hop, Jungle, and so on, but also in the case of what came before these popular genres. Black involvement in technologically-enhanced cyborg music is perhaps the definitive event of the last 80 years of western music culture.

John Cage was once scheduled to play with one of these futuristic aliens, this one in particular came from Saturn, a Saturnian time-traveller who is held now as one of the greatest experimental artists of all time, Sun Ra. Sun Ra, like Grandmaster Flash, was wired into the machine, operating in unison with it. The music of Sun Ra is a radically altered approach to the same task of Cage, Schafer, and Stockhausen, to merge with the machine to reach out to the sound of the future. Barry reminds us though, that Cage was not graceful in his engagement, referring to their duet as merely two people performing at the same time, not together. Barry uses this intersection to open the conversation of minimalism and maximalism. While Stockhausen, for example, was more open to Sun Ra’s work, and Barry recalls a moment where Stockhausen reaches out to Sun Ra to exclaim his brilliance in some performance. Sun Ra’s conceptualisation of the future can seem radical or weird to John Cage, because of one important factor that cannot be overlooked: the black factor. To Ra, to see himself and his people as being of or in the future, one has to be sure of where one comes from, and for this reason the discussion of ancestry becomes very important. For every meter into the future one wants to go, one must reach two meters back, to understand and establish the foundation upon which the future extends.

Throughout the second half of the book, Barry begins to give due notice to the lobotomising effects of capitalism on music and music culture. It has been noted that musicians are forced to become more and more entrepreneurial in their pursuits as revenue dwindles. As Capitalistic models of production continue to expand, it leaves less space for the pioneers to push forward, and we end up in this situation where the ‘airways are flooded’ with the same sounds, the only sounds that are commercial or monetizable. Not even John Cage can survive the future, and there is certainly no space in Capitalism for sound to be itself, no, sound in capitalism must be profitable, or conform to a marketable model. It reminds us of this note from before, where Zagreb simply hopes that there is a future at all, and this lack of future music, where all music is stillborn if not pressured and conditioned into a commercial object. It is without surprise that the names Mark Fisher and Simon Reynolds begin to appear, two names that seem to demarcate quality music and popular culture scholarship.

There are no simple answers to what music the future will have, if any, but the task of authors such as Barry is to continue to remind us that capitalism signals the end for music, and for music culture, and that any hope for any future at all must be informed by the struggles of the aforementioned sonic travellers. Without Sun Ra or Karlheinz Stockhausen, music would stagnate, just as Fisher and Reynolds claim. Most books published by Repeater do have this habit of eventually steering into this idea of “no future”, but considering it seems to embody critical discourse in 2020, it never fails to lose its edge.

# footnotes/links

Barry, R. (2016) The Music of the Future. Repeater Books. [𓄁](http://nikomas.memoryoftheworld.org/#/book/c168f8c9-f5e8-4823-91c6-27c562663740)

Berlioz - Euphonia, or the Musical City. [𓃱](https://urbanmusicstudies.org/2017/06/12/music-citys-origin-hector-berlioz-euphonia/)

Attali, J. (1977) Noise: The Political Economy of Music. University of Minnesota Press. [𓃰](https://nikomas.memoryoftheworld.org/#/book/90743661-a8ea-4c70-ac75-0148752a8a91)
