---
title: "On Commodification"
authors: ["nikomas.md"]
keywords: ["commodification", "Logocentrism", "Derrida", "Deleuze & Guattari", "objectification", "capitalism", "ontology of music", "sociology of music", "philosophy of music"]

---

# Introduction


There are many topics to cover in the following series of essays, forming an assemblage of concerns. Each essay attempts to address specific ideas, and each is contextualised respectively, to bring out different insights from the central subject matter. For example, the overlap between the essays “On Commodification” and “On Musicking” is clear, as both consider the Ontology of music, but each seeks to understand something different within the topic of Ontology. The overlap between each essay is left untouched, so that each essay can make sense within itself. All of the essays are either directly or indirectly concerned with rave culture, music, music scenes, and the people of music. 
There is an imperative to attack the ‘Western Aesthetic Object’, or to unpick or untangle it, or, to untangle ourselves from it, like some aberrant spectral spider’s web. It may be found that some essays require retreading similar pathways, but these reiterations are seen as necessary for the sake of clarity, and for the sake of ensuring that the overall ethos of the text can be pieced together as each path is retraced differently. As a gateway to all that this series is concerned with, we begin with ‘commodification’. 

Much of the work stems from a study of Theodore Adorno, Jacques Derrida, Gilles Deleuze, and Mark Fisher, and in the opening essay, there is a heavy focus on what is more commonly referred to as the metaphysics of presence in the work of Derrida. It is not to say that it will be easy to merge these ideas with contemporary musicology, but nonetheless musicology takes a fascinating turn when seen from this perspective.

		 	 	 		
# Part One: Logocentrism		
				
				
Within the field of Ethnomusicology, traditional or ‘Classical Western’ Musicologists have long been accused of marginalising or distrusting the role of listening, and in fact, the ear as an organ entirely, as a means of handling and experiencing music (Gilbert & Pearson, 1999: 54). 

Within a Patriarchal society, it is argued that there are key metaphysical underpinnings that frame and inform all thought, to which Derrida (1998) grants the name ‘the metaphysics of presence’ . In simple terms, everything we think and do is reducible to two assumptions, that presence and absence are separate and distinguishable, and that presence is naturally superior to absence, with a cascading effect that forces everything into a binary of either present (positive, superior), and absent (negative, inferior). It trickles down from presence and absence to include the binaries of ‘positive/negative’; ‘dominant/submissive’; ‘active/passive’; ‘masculine/feminine’; ‘right/left’; ‘up/down’; ‘forward/backward’; ‘man/woman’, and so on. 
Derrida does not present this binary as truth, but rather as a ubiquitous and problematic assumption being made by subjects living within a global capitalist ideological hegemony. Indeed, intersectionality and the language of non-binarism is necessary precisely because of the consequences of these assumptions being made. Lurking within all ‘us’ and ‘them’ divisions and prejudices is the very same set of assumptions. In order to understand why music culture worldwide is dominated by the commodity, we must understand the “logic” of the context we live in: patriarchal neoliberal capitalism. Derrida’s model of presence and absence eludes great insight to where our music culture comes from. 

At heart, the metaphysics of presence is a critique of logocentrism, and the metaphysical assumptions being made within logocentric thought. For Lacan it was more than just logocentrism that was underlying all thought and actions, proposing the term ‘phallogocentrism’, a word which today is used almost interchangeably with patriarchy (Söderbäck, 2013: 257; Derrida, 1998: lxviii).
		
Returning to the discussion at hand, within our problematic situation, whether you call it patriarchy, capitalism, or phal/logocentrism, our thoughts, actions and experiences., musical or otherwise,  are mired by these metaphysical assumptions. The grand phallogocentric assumption is the aforementioned, that 1) presence is distinguishable from absence, and that 2) the two separate binary opposites can be hierarchised in the following way: all that aligns with presence is “of the quality of presence”, and all that aligns with, or is deemed to align with, absence, is either “lacking the quality of presence”, or “of the non-quality of absence”. Here we see the prototypal Freudian image of the woman as the castrated man; as man-lacking; as man devoid of the necessarily-masculine vitality of presence and substance, as embodied by the sexual organs (Moi, 2004: 844). However, in the movement from Sigmund Freud to Jacques Lacan, there is a pleasing inversion of this, where Lacan’s women are not the castrated or lacking, but rather the man is the lacking (Lacan, 2005: 215). Here, the “male” end of the binary, is the one lacking, in that it lacks, at great consequence to itself, the quality of absence. In many ways, this Lacanian inversion of Freud’s symbolic phallus is reflective of the kind of inversion being explored within this text. 
This inversion shatters the binary-hierarchy, both revealing the fluidity of presence/absence, and the insincerity of the assumption that presence is in and of itself superior to absence. As Toril Moi (2004: 843) reminds, there really need be no theory of femininity at all, as such a requirement only seems to affirm that there is indeed a binary. By mentioning these words and using the language of patriarchal capitalism, there is no intention to reiterate these categories as truth, but rather to reiterate them as false, as after all, Derrida’s work on this topic begins primarily as a claim that the metaphysical assumptions in phal/logocentrism are highly problematic. 

For Derrida (1985: xiv), the ear, and listening, has, as with everything else, been subjected to the hierarchy of presence, and relegated into association with the absent, the feminine, the submissive, the recipient, and, consequently, in absorbing the character of absence, has become less trusted as a source of reason, or as a means to know. In place, there is a demonstrable preoccupation with, or privileging of, ‘masculinity’, ‘physicality’, and ‘presence’, and consequently ‘Image’, ‘Visual’, ‘Seeing’, and ‘Sight’. Based on the hierarchical binary form here, what is heard is not as trustworthy as what is seen, and therefore the eye is given the privilege of representing the sensory organ of presence (Gilbert & Pearson, 1999: 57). 	 
This links to the ‘re-evaluation of values’ in Friedrich Nietzsche’s work, where Zarathustra asks “Must one first batter their ears, that they may learn to hear with their eyes” (Nietszche, 2016: 62; Derrida, 1985: xiii; Shroeder, 2001: 189). In this example, Nietszche’s character suggests “penitential preachers” must destroy the ears of listeners, so that they neglect ‘the ear’ (the negative sensory organ). Who the preachers represent here is left to the reader to decide, but it is clear that the task of the preachers is to be enacted through the curtailing of any recognition of absence. 

Music is entirely in the sensory realm of the ear, so naturally this neglecting of the ear, due to its untrustworthiness in the pursuit of knowledge, is at the heart of the problems found within the study of music. Musical inquiry has always been an esoteric matter, historically seemingly like a strange cult talking their own language (referring to “music theory”). There has been a refusal to handle music on its own terms, with musicology traditionally seeking to objectify or transcribe, or convert the musical experience into something that can be handled rationally by logocentric inquiry. However, as contemporary musicology embraces fields like sociology, anthropology, psychology, and geography, the study of music becomes less and less aloof, and is slowly pulled back into the domain of a very relatable and accessible human experience. Nonetheless, by and large, people just accept that music is there, in some ‘extra space’, and it is the way it is. But beyond artist names and memorable lyrics the nature of music is still a cult matter. 
	Until these developments in post-structuralist musicology, musicologists and music theoreticians traditionally handled music in the form of ‘autonomous works of music’. Itemised, categorisable, singular, individuated pseudo-objects, embodied by the written score as the primary signifier of meaning. Due to the score being considered the primary signifier, that which is not in the score is of secondary value, so to speak, leaving only the chance to measure interval distances and mathematical or spatial patterns. The key issue at the heart of this is that music is 1) heard, and 2) transient/impermanent, two things that rational or logocentric thought cannot grasp. Yet it is not a problem limited to music, indeed all of Western culture is tainted by “phallogocentric-patriarchy” (Irigaray, 1985: 50), or an underlying and pervasive bias affecting all value and truth judgements: “We live under the illusion of a disembodied and universal cogito: a masculine subject, disguised as a neuter, upon which subjectivity is crafted and which consequently defines woman as negation and lack” (Söderbäck, 2013: 258). 

It is however undeniable that music is a unique example. Music, this unseened, transient thing, is simply out of the hands of a ‘metaphysically-masculine’ observer; it even terrorises such a subject. This is noted in Schroeder’s (2001) reading of Nietzsche’s “the listening eye”: “music, it appears, best approximates the unchanging channel of eternal recurrence, the ceaseless differentiating flows of existence, whos terror lies in its refusal to be reduced to an image” (Schroeder, 2001: 194). Music’s refusal to be reduced to an image is of fundamental importance in following this text. Regardless of this, until very recently academic study of music was obsessive about this need to convert music, and perhaps one of the strongest influences on today’s commoditized music culture begins with this ‘textcentric’ or ‘scorecentric’ tradition of musicology. For centuries, music was religiously transcribed, only after which a work could be taken seriously (Nettl, 2005: 89). As Irigaray (1985: 50) identifies, the idea of performance or art as representative has some linguistic Freudian slips; representation is just that, re-presentation, ‘re-presencing’ something, as if without presence it is not, so to speak, real, or worthy of enquiry. The handling of music in this way, with the score being the centre of the music, ultimately initiates a long decline into what could be called the objectification of music (Denora, 2003: 5; Adorno, 1976: 197). Until the score existed, there was no object that a work of music could really be attached to, setting the premise for a century of reification from wax cylinders and vinyl records to digital files. 
By converting all these metaphysically absent or unrepresentable transiences, which are only detectable by the ear, into a visual, quantifiable form, music is given a presence. It gives credence to Derrida’s occasional usage of the specific phrase ‘phallogocentric project’, as it correctly identifies that the ideology of phallogocentrism behaves as a kind of immense PR campaign that works towards furthering the project, where all that is not objectifiable is trivialised or just banished from consciousness. Derrida accuses the likes of Kant of “by-passing the ear”, and rather than investigating music on its own unseeable terms, it is ascribed a fictitious presence (falsely or incompletely reduced to an image), and that fiction is centralised.

Above all, this renders music disconnected from reality, as the metaphysical assumptions we are constantly assuming present a reality that cannot accommodate music. With the study of music interrupted by such an ideology of presence, certain aspects of music were neglected and marginalised, such as emotion, colour and grain, which are cast in association with the feminine or absent (Gilbert & Pearson, 1999: 61). Such things as Rhythm were also sidelined, being associated with blackness, as well as the social dimensions of music which contrast vividly against capitalism’s dependency on the ideology of sovereign individualism. 

The industrialisation of music and the reification of music into distributable items like LPs and CDs firmly cemented this way of understanding music. It is common to be vaguely aware that a song is more than just the studio recording, and that any work of music can be played in a variety of ways and places and while being different, remain the same work. If a singer sings a song slightly slower, it is still the same song. So where is the song if not on the CD? The second you actually step into this discussion the “rational floor” is pulled out from underneath you, as it is no longer in the realm of anything tangibly present. “Where is the music” is exactly the kind of aloof question that terrorises most, as it has become symbolic for the broader critique of rationalism at the heart of many of the theorists cited here. 
	


Industrial music

It is no coincidence that traditional western classical musicology arose post-enlightenment, holding hands with rising capitalism. In the same way that phallogocentrism influences music perception, capitalism does the same, perhaps even more effectively. A number of things happened over a half century which turned the norms of the study of music upside down. At the point where music could be transcribed, even the seemingly uncapturable music was primed to join the other arts in a near-unified object-oriented culture. The phallogocentric project essentially territorialised music, converting it into a bone to chew on, once again reaffirming that indeed, the present-object is the only source of truth, as was always assumed. Within visual art cultures, at least up until a certain turning point in the 20th Century, this object-oriented phallogocentric culture was already well established, the power/value of the art was contained within the object, and the context was a mere shadow to the text. It is no coincidence that our art culture became what it did, if the thoughts and actions of the artists and audience are indeed influenced by the metaphysical assumptions of phallogocentrism; it is not surprising at all that the mode of organising art is that of autonomous objects within an ideology of sovereign individuals. Such a paradigm presents a rather Newtonian reality of distinct separations. It is also no surprise that such a presentation of music benefits capitalism, which is born of the same phallogocentric desire. At one time, you might say that societies were conditioned to think and act in certain ways, but now we collectively condition ourselves, reiterating the same ideology in all of our thoughts and actions, and this notion becomes central to a later discussion.  
	
The link between objects and commodities is quite clear, and after a near-century of treating music primarily as something rational or present, the musical quasi-object was primed to be an ideal host for commodity value. When Walter Benjamin wrote “In the Age of Mechanical Reproduction”, he described how the reproducibility of art could perhaps be something revolutionary based on his grand thesis that Fascism, a rather purified take on phallogocentric politics, had turned art into something that perpetuated phallogocentric ideology. The gallery paradigm established ritualised viewing conditions, where all art must be visited and seen, and seen on exactly the terms laid out by the curator (Benjamin, 2008: 221; Sinha, 2007: 1). It is clear why some understandably jumpy marxists in the 1930s would see the Fascism very presently within such an art culture. In other words, turning art into a matter of objects subtly conditions the art viewers into a particular ideology and worldview, that of objects, of physicality, of presence, and ultimately of patriarchy. Adorno responded to Benjamin with justified cynicism, reminding about the dangerous potential these growing industrialised cultural networks have for mass influence and manipulation, especially music and audiovisual oriented culture due to their power to inculcate modes of consciousness, and heighten or suppress imaginative and cognitive capacities (Denora, 2003: 10). 
Perhaps we did escape from the gallery, but in place we see something equally problematic, if not worse. As Byung-Chul Han (2017) describes, we have moved on from the traditional Fascism of Adorno and Benjamin, into a more covert form of control, often shorthanded as Neoliberalism or Capitalist Realism. Our art culture reflects that too, moving away from the more obviously phallogocentric industry of galleries and objects, to the more subtle phallogocentrism of digitized quasi-objects and streaming-based access. Our situation today is not necessarily better, and no matter what has changed, we can continue to use Benjamin and Adorno’s analysis to understand how our art culture today is representative of our social and political culture. An upcoming book by The Acid Left’s Mike Watson (2021) agrees with the fundamental claim here, that the Frankfurt school predicted Capitalist Realism, and therefore continues to offer some of the best frameworks for understanding what Capitalist Realism is. 
At the minimum, Adorno ‘predicted’ a diminished capacity for imagination would arise if no changes came to our music culture; no changes came to our music culture, and now Fisher (2009: 6) writes that our main concern today is a lack of the necessary imaginative capacity to think of an alternative to industrialised, digitized capitalism.

Admittedly, there are a number of things we must be aware of before settling on Adorno as the root of our perspective here. For starters, we are no longer operating within a traditional marxist framework, either moving into post-marxism, or moving away from Marx’s analysis of Capital towards Deleuze & Guattari’s. It was convenient in the time of Adorno to consider the force of oppression as a singular, composite other, but post-marxist and Deleuzoguattarian perspectives now present the forces of oppression as internal, opposed to external. Neoliberalism and Capitalism Realism are considered more sinister than traditional Fascism because it attempts to hide, teaching us to maintain our own oppression from within ourselves, rather than being disciplined through external punishment. 
For example, the post-marxist sociological framework known as Actor-Network Theory, accredited to one Bruno Latour, presents a music industry that contains us within it; we, the actors, the doers, the buyers and sellers, are all intertwined into a grand, rhizomatic entity. The music industry is not just a “them” anymore, but an “us”. We, perhaps to different extents, continuously enact the phallogocentric project, as embedded within our thoughts and actions is a tendency towards perpetuating what has been taught to us, or what has been observed in reality. If Derrida is right that patriarchal society has been engineered to hide from sight that which does not ‘promote’ it, then we have been “seeing” a precomposed, pre-ideologised reality, one that tricks the viewer into making the necessary metaphysical assumptions. We think music is an object because that is how we have experienced it, and the lack of imaginative capacities or alternatives offers no means of negation to this assumption. We think music is either a commodity or a spectacle because that is how we have experienced it until now, and with no means of negation, we have no way of seeing it alternatively. Nothing about a rock concert can offer us a way of understanding music differently to spectacles, the stage/audience spatial division reinforces a hierarchy immediately, and even naming the attendees “the audience” implies a static observer instead of an active participant. How we imagine the reality we operate within influences the decisions we make regarding how to operate within it. First, we learned that music was an object, within the context of traditional modernist Fascism, then, as Fascism mutated into postmodern Capitalist Realism, the musical objects were commoditized to high hell.

Amongst others, Christopher Small (1998) pushed for the refiguring of the language of music, from a noun to a verb, or from music to musicking. The foregrounding of the active, procedural, and social elements of music became central to the growth of musicology away from the classical traditions. This perspective was found within the radical field of Ethnomusicology through the application of the Frankfurt school, as well as ideas from Sociology and Anthropology, to the study of music. It was stated previously that mechanical reproduction shattered the illusion of the power of the object, revealing that the affectivity of any object or text is born of a dialectic between the object/text and the context. You could even say that the object/context is unseparated or unionised. Music, in the lens of ethnomusicology, is a developed humanistic capacity, one that takes a form, or manifests depending on all the other values and practices and beliefs that any musical human has. The “tribes” make “tribal” music, the capitalists make capitalistic music, the workers make working music, as all adhere to and believe, and therefore reiterate, different ideologies. It is an extremely important distinction, whether a music culture frames the audience as active or static, as the very enactment of a culture that implies the audience is static, teaches the audience to behave like a static entity in other areas of life. None of this happens in a vacuum, and even musical etiquettes bleed into other etiquettes. The gallery and the concerto do precisely this, they teach a subject their place in society, or rather, teach a subject how to interact with reality at wide, as a static observer.


# Part 2: Today

It is hard to imagine, with our limited imaginative capacities, how the situation can be rectified, there aren’t many options art producers and consumers have to by-pass the production channels of capitalism, let alone make a serious challenge to the metaphysical assumptions underpinning art and culture and so on. Furthermore, it is not even just a case of trying to by-pass capitalistic distribution, because phallogocentrism flows through us, and, in many cases, our desire mirrors phallogocentric desire. Our musical dreams are built out of this desire, to either be the star, to make vinyl records, to earn money with a music career. 

Underground Electronic Dance music is undoubtedly an area of particular interest here, as it is one of the many battlefields these ideological contests are taking place. Underground Electronic Dance music (UEDM) has maintained some reputation for revolution, either in the simple association between the fall of the Berlin Wall and Techno, or the temporal freedom of Warehouse Music in Chicago or New York, or, more abstractly, the Deleuzean dialogue of rave and presexual ecstatic communion (Gilbert & Pearson, 1999: 66). It is a realm of music that embraces the language of the new musicologies, where everyone involved is an important part of the shared communal experience, a procedural, participatory social situation, where the DJ is no higher than the dancer, and the producers and promoters and barkeepers can all more clearly be seen to play an important role in the musicking or music event. While this is generalised, a contrasting model to this is what we described before with rock concerts, where everything is structured around a hard division between performer and listener, and the audience stares up in amazement at the godlike rock star. The phallic guitar solo and the spectacularized experience present a music culture of divisions, and the patriarchal essence behind rock music is unmistakable. 
In 90s rave, this transition from audience to participant is described in many ways, such as with the phrase “the decline of the figure and the rise of the ground”, a notion discussed by Philip Tagg (1994), where a decentralisation of masculine figures occurs, not just in the cultural dimensions of music, but the musicological dimensions too; underground music simply has less vocals, less figures, less focal points, and rather exaggerates the ground or space. A prime example of this is within the micro/minimal house movements, of which ro-minimalism is one. As will be discussed later, the aesthetic sparseness or incompleteness of the music of producers such as Rhadoo or Ricardo Villalobos is palpable, seeming to deliberately lack a central figure, and in place present an intricately designed ground or space. 

Such developments are increasingly difficult to commoditize, as the movement away from figures reflects a movement away from the newtonian reality of distinct separations, for that is essentially what Derrida hopes to deconstruct in his examination of distinct separations. If there is no longer a figure, how can one define the track, and how can something be sold if we are not sure what exactly it is we are buying. 

There are also observable trends in underground music where old habits of buying and owning music in the form of records is declining, not just replaced by a culture of digitized files, but replaced by a culture of non-buying, and capitalism has struggled for a long time with this, manifesting various unbelievable systems like Streaming and NFTs; desperate attempts to maintain the prevalence of the commodity in an evolving music culture. Once again the ‘absent’ appears to escape the present. 
The practices of distribution in micro house and techno music cultures is emblematic of this, where either the tracks made have no names, or the name cannot be found anywhere, and even if you have money, you may never find where to get or possess the music. It seems to send a clear anti-capitalist message, stop trying to collect and stratify music, and just experience it. Many of the conceptual ideas revolving around someone like Ricardo Villalobos involve trying to create a kind of electronic music that understands what electronic music really is to the people, and what it can offer to people without conceding ground to commodification, objectification, spectacularization, or consumerism. The work of Villalobos is undeniably experimental, but it is often misunderstood as to what it is experimenting with.  

For example, in underground/micro/ro-minimal, or whatever we are currently calling that sound, the change happens in a way that is not supposed to be noticed, or recognisable, and it often tries not to seem like a linear narrative; the raver just suddenly notices they aren’t where they were 5 minutes ago, experiencing a vivid distortion of the passage of time, which contributes to the experience of desubjectification.
	Depending on how you see it, this minimalism and repetivity is either emblematic of Adorno’s unlistened music, or, it is the opposite, a music so listened-to, that the introduction of micro changes become as vivid as any final grand orchestral maneuver. The decline of the figure and the subsequent rise of the ground with the whole micro-movement, from Mille Plateaux to Sunrise Hub, led to a music that arguably attempts to disengage the listener from the hold of invasive, experience interrupting logocentric thought. The ro-minimalist movement is connected to a history of micro and glitch aesthetics merging with house music, dating back at least to the mid-nineties with two exemplary labels, both of which are ironically, or perhaps aptly, from Frankfurt; Perlon and Mille Plateaux. Mille Plateaux takes its name from Gilles Deleuze and Felix Guattari’s text of the same name, and the founder Achim Szepanski is an ardent and distinguished critical theorist. 
					
The deliberately mysterious phenomenon of rominimalism offers some window into how music scenes and cultural producers today are engaging with the problems that come with objectification, and in turn, the commodification of music. If we do not experiment with distribution of music, we will not escape the objectifying feedback loop of buying and selling music. If we remember the gallery, and how the experience of the gallery, its location, its aesthetic, and its thresholds become the frame of the art, we can also see how the buying and selling of music, the process of adding to cart and digital payments, become the very frame of the work. The format, the way the music is obtained, the way you come into contact with the music is the frame. The idea of a bargain shows how the price itself is the frame, and the price can impart a great sense of value on the object, and not just in the literal sense of capital.
					
It has always been a personal fascination to ask what Adorno would have made of rave, the cultural setting within which this rominimalism operates. While it is not entirely representative of all dance music, rominimalism presents something of a paradox where, without confronting and unlearning phallogocentric sensory processing and cognition, ro-minimal music can seem dry, meaningful, formless, and unchanging, yet, if a listener embraces attentiveness (Cichosz, 2014) and achieves an absence of intrusive logocentric thoughts, ro-minimal music becomes deeply capable of expanding imaginative capacities. As will be shown in another essay, changing music composition practices, as exemplified by ro-minimalism, can teach people about different narrative pathways, or indeed, non-narrative progression; expanding the capacity to imagine an alternative is a fundamental part of Fisher’s path to Post-capitalism. 
			
It is fun to say that Hegel predicted the end of the future, or that Adorno predicted capitalist realism, and while there is undoubtedly some ironic humour here, looking at the precise concerns of Adorno make for an insightful reading on what we have around us. The parallels between Adorno’s worries, and the observations of authors such as Simon Reynolds is astonishing. One thing we might attribute to Adorno is the notion of “music to not be listened to”, a music that essentially fills the void of aural focus, without actually demanding any effort or attention be paid. Commonly this might be called something like elevator music, or perhaps others would say “thievery corporation”, or Jazz; a hypothetical music that offers nothing to listen to, but eliminates the need to listen to something. Where Adorno is interpreted as a reactionary grumpy old man who doesn’t like new music, the pre-Derridean philosopher accurately identifies something that goes on to become part of Derrida and Deleuze’s work. It was not just that Adorno was saying that new music is not worth listening to, or not intended to be listened to, but that it rather intended to contribute to the overall devaluation of listening. Redirect the focus away from the ears and towards the eyes. 
Derrida, in his metaphysics of presence, adds the idea of a music that is not made to be ‘not-listened’ to, but rather to be seen. Adorno recognised the centrality of Image in the rise of Fascism, but it was not until the time of Deleuze where the rhetoric of “Face” is established as the core of Fascism: “It is impossible to conceive of a fascism without the hegemony of the face” (Terranova, 2004: 143). The key aim of the phallogocentric project, as manifested through the practices of objectification and reification, is to give that which has no face, a face, in order to maintain the hegemony of presence, and of that which is seen. Capitalism today seems like a purification of this ideology of face, being truly faceless; it is all face, we are all face, everything is capitalism. As we know from Fisher, there is a universe beyond capitalism, but it cannot be seen.

It can initially be confusing to think what Adorno might have meant when he spoke of a music that is made without intention to be heard, or rather, a music made for looking at, but when contextualised with Deleuzian notions of ‘face’ and ‘image’, and these ideas of the attempted rational interrogation of irrational inputs, and Nietzsche’s “listening with the eyes”, a more substantial visualisation can be achieved. In response to Schroeder (2001: 194), it seems as though music has been infiltrated, and this irreducibility of music seems less and less true.  Such arguments can lead to an outright suspicion of anything visual, as if it is all territorialized and engineered for coercion: must they gouge out their eyes so that they may learn to see with their ears? 

An obvious example of this is the undeniably fantastic “A Colours Show” on YouTube, with tracks like “Blue Lights” by Jorja Smith. For starters, it’s a million dollar beat, that watery lead is stunning and the grain is undeniably in focus, but the emphasis on the visual elements seem to pull attention away from the sound; the pink nails against all that dark blue, and there is no holding back on exhibiting the beauty of the artist. 
The same goes for “The Essence” by Giggs; the track is so smooth, and a reminder of how untouchable Giggs is, no one can say so few words and yet carry so much power. Yet, it is hard to go back to the original music video after seeing the Colours TV. The 60fps recording of someone moving so slowly and smoothly that it looks ghostly in the recording.  However, it would be hard to argue that all audio-visual experiences are “tainted” by the visual, as this begins to sound like a classic old-school communist perspective, where the second you add rounded corners to a button, you have given in to Venture Capitalism; so where does this leave Colours? 

By and large, Colours makes a clear statement that quality must be designer level, and pessimistic readings of Colours would position them as “rescuing” people from a natural ugliness; but there is no cessation of consumption, as we the viewers, by and large, already agree. There are no credits for who made the beat in Blue Lights, the million dollar backing track is just a backdrop for the figure; no mention of Ben Joyce, Engine Ears, Guy Bonnet or Roland Romanelli anywhere on screen. Ironically, given the “feminine aesthetic” of Blue Lights, the power of the “feminine”, the power of sound, of music, of listening, is hidden behind the falsely-inflated power of the visual. 
To reiterate, the issue here is not necessarily that there is a “beautiful person” on screen, and neither is there any interest in arguing that the music is inferior or superior in any way because of how the artist looks. The interest here specifically concerns how the visual dimensions may invite logocentric thoughts that intercept and interrupt the perception of sound. 

“A Colours Show” also seems to play into the kind of diminishing imaginative capacities narrative attributed here to Adorno and Fisher, where we, through our mass engagement in Colours, apparently prefer small rotational changes and themes, to other kinds of change. Each video of Colours is defined by a rotation of similar artists, with a different colour palette on the walls and the clothes. It is not a leap to suggest that there could be problems with this, as, if our culture of music consumption can bleed into our political culture, our love for rotating the colour palette could be used as a cynical analogy to the state of neoliberal politics in the West; we just keep rotating the colour palette without actually changing anything too much. 

More close to home, the state of contradiction described here can be seen clearly in the case of rominimalism. For example, the rominimal artists sell music, as itemized tracks on e-commerce sites or in record stores; they press records and sell them, they work with distribution agencies and designers. Yet, on the other hand, they are known for playing rare music, or unreleased music, music made by themselves or people they know. What is being sold is not what is being played, or in some cases what is sold is what was played already last year. There is commoditization involved, but it is, for lack of a better word, weird. This approach carries a sense of post-irony in its self-referential cynicism.
Secondly, the minimal music here is reminiscent of the kind of rotational micro-changes that were discussed before in regard to “A Colours Show”, the consistency of format in each track is not just enjoyed, but necessary for the DJing component. However, when considering the rhetoric of the ear and listening within this text, it could be argued that, because the micro-changes in romininal music are not visual, they are only accessible through the ear. Furthermore, because the changes are so small, and develop over such a time, they are observed through attentive listening. It encourages the foregrounding of something that has been neglected. 

Minimalism itself is caught in a contradiction, however, with clear connections to the neo-aristocratic traditions of Brian Eno or John Cage, music that is utterly unobtainable to the working class and therefore reinforcing class boundaries, in this case knowledge and access to education. On the other hand, part of the popular discussion of Rominimalism includes the idea that minimalism, in this case, attempts to be democratising in affording as many people access as possible. Despite being obscure, it doesn’t contain anything within it that requires unobtainable knowledge to participate; anyone can follow it, as all it asks it to be listened to, carefully. 

As a final example, the rominimal artists created Sunrise Hub in December 2018, a project that intended to push the movement to its next stage of potential. A dedicated studio, recording and broadcasting space to push their sound and culture far and wide. One of the most eye-opening things about it was the visuals; video mapping that separated the subject from the background, and projected textures and light patterns on each layer. Just as was seen with “Colours”, there are so many contradictions here, where the visual element seems to contradict the rominimal ideology, but, at the same time, not having beautiful, designer visuals that evolve in the same way the music evolves, would also seem contradictory to rominimal; of course they have designer visuals, they are funded cyborgs with a lot of both privileged and earned knowledge and talent in digital production. They are obscuring the figure’s identity, yet still emphasising the figure nonetheless, although importantly it is a post-human figure. They aren’t commodifying the tracks, but they are still reinforcing the spectator-consumer model through live streams. 

This endless loop requires a lot of unpicking, and in many ways, that is the intention of the essays that are published after this one, to deconstruct the preceding paradoxes and build a framework for discussing these issues. Is raving revolutionary? Are raves grounds of counterculture? Is rave an opiate of the masses or pathway to postcapitalist desire?

It can almost seem as if this is some miraculous breakthrough, where renegade Romanians are a driving force behind the fragmentation and deconstruction of the object and commodity, but the spectre of Adorno lingers above us, frowning, as if to say: “will you fall for it again?”. 
In light of some of the socio-political ground we have covered, it is difficult to sustain any excitement in this development. Are we more enlightened, to begin seeing ourselves as active participants in music, as many cultures have done for centuries? Not likely, it just reflects the larger winds of change; we are no longer in traditional Fascism, as passive subjects (the ones who are cast down), but within Capitalist Realism, where we are all enactors and active participants in our own doom. Aforementioned Byung-Chul Han describes this as the transition from “subjects” to “projects” in his opening to the era defining text “psychopolitics” (2017). The wardens have left the prison, and we actively maintain it ourselves. There is an uncanny correlation between the transition from Fascism to Neoliberalism, from passive subjugation to active auto-subjugation, and the sudden emergence of theories of music in the west where the audience is described as active. If one is to believe there has been any progress in our understanding of music, are they not just reiterating the darkest illusions of neoliberalism? The illusion of progressing towards the light, despite regressing further, and further with each thought and action. This implicates everything from protest to revolution, and questions whether there is any means for producing change within every single action we consider positive. The real depth of Capitalist Realism is that there are simply no “good” choices left to make, all alternatives to perpetuation have been eliminated or hidden from view. All revolutionary options are just more patriarchy, more capitalism, more oppression. This opens up a tangential plateau, where we can once again look at music, but from a perspective of revolution, or from the perspective of the death of revolution, and the end of progress. We likely won’t know if what we are doing now, or what Sunrise Hub is doing, will have any impact until it is too late. 

While such implications are worrying, they loom over us without due explanation. So far it has been described that, using the perspective of Derrida’s metaphysics, we can more clearly understand the transition from the time of Adorno, or Foucault, or Guy de Bord, to the era of Mark Fisher, Byung-Chul Han, and Rosi Bradiotti, from the beginning of the rise of the final stage of capitalism, to the realisation of those conditions. Music culture changed dramatically within this transition, from primarily something experienced in a concert hall, with the traditional authoritarian divisions, to something diverse that exists in multiple ways, as objects, collectables, spectacles, participatory events, but all of which are capitalism. We said before that capitalists make capitalistic music, and this can be seen today, all around us. We are all active participants in capitalist music, even the record label this is published on, somewhat hypocritically publishes music despite also publishing a suicidal critique of publishing music. To what extent is Crossdressing Diogenes just more capitalist realism? Our concerns here are not just given out of a sense of despair at others, but a deep concern that what has been stated here must also apply to ourselves.

Until next time. 


# References

Adorno, T. (1976) Introduction to the Sociology of Music. English Translation. The Seabury Press. ISBN: 0-8164-9266-2 [▒](https://nikomas.memoryoftheworld.org/#/book/ed41da1e-84dc-47cf-84da-c885d138aaad)

Benjamin, W. (2008) The Work of Art in the Age of Mechanical Reproduction. Penguin Great Ideas. ISBN: 0-141-03619-2. [▒](https://nikomas.memoryoftheworld.org/#/book/48b2f706-bbd8-462b-817b-065cddd7aa8d)

Byung-Chul Han (2017) Psychopolitics: Neoliberalism and the New Technologies of Power. Verso Books. ISBN: 979-1-78478-578-9. [▒](https://nikomas.memoryoftheworld.org/#/book/656a28dc-42de-441e-bd0b-3ae3edefc9aa)

Cichosz, M. (2014) The Potential of Paying Attention: Tripping and the ethics of affective attentiveness. Emotion, Space and Society. Vol. 10, pp. 55-62.  [▒](https://drive.google.com/file/d/1XxyXVqn5wg6UtfecppZKn8XXLDaLVu_z/view?usp=sharing)

Denora, T. (2003) After Adorno: Rethinking Music Sociology. Cambridge University Press. ISBN: 0-511-06289-3. [▒](https://nikomas.memoryoftheworld.org/#/book/1bf0d8d3-716b-4b1e-8de6-2ee75f22a229)

Derrida, J. (1985) The Ear of the Other: Otobiographies. Montreal Schocken Books. ISBN: 0-8052-3953-7. [▒](https://nikomas.memoryoftheworld.org/#/book/6707dde7-3e53-4d17-8b34-43b8ddfc8568)

Derrida, J. (1998) Of Grammatology. (Corrected Ed.). Baltimore: John Hopkins University Press. ISBN: 0-801-858305 [▒](https://nikomas.memoryoftheworld.org/#/book/a36e566e-1eae-4c71-91ef-73061fb22356)

Fisher, M. (2009) Capitalist Realism: Is There No Alternative? Zero Books. ISBN: 1-846-94317-5 [▒](https://nikomas.memoryoftheworld.org/#/book/13a48752-f776-436e-8f21-fcc436dab6dd)

Gilbert, J., & Pearson, E. (1999) Discographies: Dance Music, Culture and the Politics of Sound. Psychology Press. ISBN: 9780415170338 [▒](https://nikomas.memoryoftheworld.org/#/book/99e6a585-b1e6-4b0c-af18-d032adf5efdc)

Irigaray, L. (1985) Speculum of the Other Woman. Cornell University Press. ISBN: 0-8014-1663-9. [▒](https://nikomas.memoryoftheworld.org/#/book/97547cee-74ce-4d51-a556-a03efdff90b5)

Lacan, J. (2005) Ecrits: A Selection. Alan Sheridan Translation. London: Routledge. ISBN: 0-203-99583-X. [▒](https://nikomas.memoryoftheworld.org/#/book/37e3070b-d81e-444d-ad20-550f64688e54)	

Moi, T. (2004) From Femininity to Finitude: Freud, Lacan, and Feminism, Again. Signs: Journal of Women in Culture and Society, Vol. 29, No. 3, pp. 843-878. [▒](https://drive.google.com/file/d/1wvPaLcrwbeCLQgo7V-7gOl7GCa-KykCr/view?usp=sharing)

Nettl, B. (2005) Ethnomusicology: Thirty-One Issues and Concepts. The University of Illinois Press. ISBN: 0-252-03033-8. [▒](https://nikomas.memoryoftheworld.org/#/book/d257342a-3b18-4b39-80ee-9551b0ba5ac5)

Nietszche, F. (2016) Thus Spake Zarathustra: A Book for All and None. Project Gutenberg ebook edition. [▒](https://nikomas.memoryoftheworld.org/#/book/8c109f02-5daf-429c-9460-0d6f94d7a828)

Shroeder, B. (2001) The Listening Eye: Nietzsche and Levinas. Research in Phenomenology. Vol. 31, pp. 188-202. [▒](https://drive.google.com/file/d/1CpO-Eyom_xm1pWFRH-LLPQP1A6h6igY0/view?usp=sharing)

Sinha, A. (2007) Walter Benjamin and the Virtual. Transformations. 2007 Issue, No. 15. [▒](https://drive.google.com/file/d/1XoCejry-Dant1-ZpqYo3rBymNp_wYfvh/view?usp=sharing)

Small, C. (1998) Musicking: The Meanings of Performing and Listening. Wesleyan University Press. ISBN: 0-819-52257-0 [▒](https://nikomas.memoryoftheworld.org/#/book/6854aab1-e808-4907-a63a-4dd003f81bf8)

Söderbäck, F. (2013) Being in the Present: Derrida and Irigaray on the metaphysics of Presence. The Journal of Speculative Philosophy. Vol. 27, No. 3, pp. 253-264. [▒](https://drive.google.com/file/d/1XSa9MKL7Duyg101UuNCLl1VsfBRCla0-/view?usp=sharing)

Terranova, T. (2004) Network Culture: Politics for the Information Age. Pluto Press. ISBN: 0-7453-1749-9. [▒](https://nikomas.memoryoftheworld.org/#/book/2a867bc0-c60d-4683-bf37-d6d1571ed610)

Watson, M. (2021) The Memeing of Mark Fisher: How the Frankfurt School Foresaw Capitalist Realism. Zero Books. [▒](https://nikomas.memoryoftheworld.org/#/book/43dac793-b0d6-49ec-a7c2-81597ed92207)








