---
title: "On Tripping"
authors: ["nikomas.md"]
keywords: ["Tripping", "consciousness", "Deleuze & Guattari", "Maria Cichosz", "deep listening", "affects", "rave", "music", "music philosophy" ]

---

# Essay 02: On Tripping



## Paying attention to affects


The interest in such a thing as Tripping, a popular term to describe numerous experiential and existential phenomena, becomes even greater when read in Deleuzoguttarian terms. Multiple participants in this emergent Deleuzian framework take on the challenge of reconceptualising what tripping means or what defines a trip, such as Tim Jordan in the essay “Collective Bodies”, Jeremy Gilbert’s book “Discographies”, Maria Cichosz in the essay “The Potential of Paying Attention”, as well as the entire publishing house Mille Plateaux, who most recently published an extended compendium of Deleuzoguattarian essays on non-music, underground, and rave-tangential topics (See “The Ultraback of Music”). A reading of these texts provides an interpretation of the musicking-raving-tripping—machine which once again makes the case for the salutogenesis of rave culture within the context of trying to mitigate or untangle the tensions that arise within late-stage capitalism.  

In the last essay, we laid the groundwork necessary to explore these topics, including Jacques Derrida’s metaphysics of presence, where it is argued that our language and understanding is constructed in relation to a number of unchallenged assumptions or biases. A shorthand term for this is logocentrism, a word that when used in relation to Derrida refers to the unconscious creation of a binary and hierarchical metaphysics that underpin our values and actions. It roughly suggests that through self-reinforcing practices, we have learned to see the self as separate from the other, as objects within environments, as an array of atoms, distinct and separate. It follows that we over-value the physical, as an extension of what we have learned to conceive as presence, or we obsess over the material, or in other words we disregard the immaterial as an extension of absence. In the framework of logocentrism, the present outranks the absent, and it is not considered possible to know anything about the absent, due to how logocentrism conditions our view of knowledge as a matter of presence and material; a matter of fact. Only what is present matters because only what is present can be known. Even the word for “important”, “relevant” or “meaningful” in English, “does it matter?”, overlaps with the principle word for substance, matter. 

As we know, this leaves matters of music, subjectivity, emotion, tripping, and so on, as simply out of the hands of explanation. Music is impermanent, fleeting, immaterial, and it has been described as something which terrorises rationalism. Study of rave culture, for example, has become so much about the pharmacology of drugs or the study of niche genre barriers and patterns of categorising rave music. It is only within a framework that specifically challenges the mistakes of logocentrism where the study of rave becomes exciting again. One of the authors mentioned above, Maria Cichosz, offered a reading of tripping which, if not directly intending to, bridged a number of lingering, ununified concepts that this essay is dedicated to. 

We begin with a discussion of listening modes. We do not engage with every sound in the same way, and based on how we listen to something, we are able to obtain different information from the sound. Without rebuilding any problematic system of categories, or without trying to ‘label’ individuated modes of listening, we can deconstruct and engage with perceived sounds to determine such information as: location, cause, semantic meaning, symbolic associations, aesthetics, grain, and so on.  We react to sound, and do not always consciously choose how we might listen to something that throws itself at us. To say that we have to “get ready” or “position ourselves” to listen to music is quite relatable, and quite to the point. The way we savor and engage with music or poetry is achieved when we position ourselves in such a way. Clear the mind, relax, and so on; somehow we implicitly understand this idea of a listening position. 

Should we be randomly thrown into the Jungle, we might immediately become more grateful for our ears, which in the frightening intensity of the present moment are as important as our eyes, which in the culture of phallogocentric capitalist modernity are given full intellectual authority; Derrida often accuses Kant of bypassing or neglecting the ear entirely as if nothing can be learned from anything experienced through the ear. When handling in-coming content, or incoming sensual stimuli, the perceptive faculties work quickly to determine the nature of the stimuli and how it might best be responded to (Chion, 2019; 57).  In the Jungle, for example, we might find ourselves immediately listening more, and listening in multiple modes simultaneously, as we examine layer after layer of sound trying to determine what is around us in an environment so visually dense that the eyes can do no more than determine the very most immediate surroundings. A more specific example for our interest would be the case of hearing a Tiger’s roar, something surely capable of inducing fight or flight responses, suggesting that the determination of whether a sound is something immediately dangerous is happening extremely quickly, creating immediate responses or shifts in consciousness. In the presence of such a sound in such a situation, an observer may be more concerned with “where” and “what” rather than  “why”, “how”, or “in what manner”. This is easy to see as an evolutionary function, as pausing to discern and savor the timbre of a tiger roaring may result in a fairly brutal death; perhaps only when one reaches safety and thinks retrospectively about the incident do the aesthetic dimensions really become clear or tangible. 

As an extension of this, we can also say that when listening to what we recognise to be a human voice automatically shifts us towards a kind of listening that examines the contours of a sonic stimulus for semantic forms; we can examine these stimuli from various angles through the use of these different modes of listening which can best be thought of as different readings of the same information with an interest, focus or privileging of specific properties. Due to the way we imbue our perceived reality with symbolism, the topography of the sounds can be read in so many ways. As said previously, it is preferable to categorise these varying engagements but it is at least important to recognise that we need to inspect sonic stimuli in different ways to ascertain the different information, and such things as “aesthetic listening”  or “semantic listening” simply mean an act of perceiving sound while the one perceiving is focusing on certain properties of the sound in order to ascertain something specific from it. 

Following the implications here, Cichosz describes a mode of listening, or the practice of a specific way of handling sound that is not in search of spatial information, semantic information, or aesthetic information, but something further. While it is unsatisfying on many levels, it is a kind of listening which forces many authors to resort to new age language to describe, such as describing it as a meditative or yogic practice, or describing it as the practice of listening to what is not sounding, to take the sound coming in and to consider its negative contours. Such a thing is the sonic equivalent of a rather famous “samurai technique” popularised through film and popular media, where some skilled monk or ninja holds one arm out straight in front, with two fingers pointing vertically; the mythology goes that such a posture is maintained so that one can practice trying to see the gap between the top of the finger, and the background behind. To focus on and attempt to conceive of that negative space is to practice something that can shift consciousness in such a way that the gurus and teachers have claimed can heighten the senses or some other benefit. However, using the framework of Deleuze and Derrida, there may not be so much need for new age rhetoric. Deleuze becomes more relevant in later parts of this text, but for now the Derridean framework laid out until now allows for us to argue that rather than a spiritual practice, Cichosz’s “deep listening” is something conceivable as another mode of listening, another perspective to view sound from, which in this case does not allow for semantic content to be observed, but other information that is less easily given a label. The assumption yet unexplained is that the act of “deep listening” can be consequential of, or contributive to, other composite shifts or movements in consciousness. Whatever can be achieved through the state of attentiveness or trip attained through a deep listening, is comparable to tripping in the sense of rave; perhaps even it could be argued that the rave situation is set up as a way of collectively getting to whatever it is that is achieved through attentiveness. 

Let's break this down more. At the centre of these arguments is the claim that the lack of imaginative capacity that has been commonly cited as a major component of why we are struggling so much to imagine something beyond capitalism by authors from Adorno in the 1940s to Fisher a decade ago, can be confronted through practices that understand why the anomalies which create new knowledge and thought are lost during logocentric examinations of incoming stimuli. If, as Cichosz suggests, the logocentric mind can be temporarily halted, we may be able to experience reality with all of its anomalies intact. Psychedelic trips can be so impactful on a person, not for spiritual reasons or reasons that implicate a metaphysical soul, but because they reveal a lot of otherwise discounted anomalies at once, which can really shatter how someone understands themselves and reality; it can force a major restructuring of information categories. It’s not a matter of being given new insights from an external entity, but switching a particular filter off, or perhaps switching a particular variable off in the computation of our internal perceptual simulation. 

To be clear, despite the seeming vengeance being directed toward logocentrism, or dare say, “science”, there is not claim being made there is no use for what otherwise might simply be called rationalist enquiry, and this paper is not in of itself a complaint about the reverence we have towards mathematics or even logic-bros, it is simply the recognition that fully and completely committing to rationalism, logocentrism, or scientism, is creating huge problems in our ability to develop as a community. Technology is not something to be hated or feared, and no one can discount the application of physics or mathematics in pursuing engineering and technological feats, but matters of absence are vital in conceiving of how technology can be used for the better, or, to hesitantly use the word, ethically. 
	
In describing a trip, Cichosz first begins by using the phrase: “where the body becomes the Body without Organs, a connection of desires, conjunction of flows, continuum of intensities”. Much of this text is about the concept of ‘affects’, discussed as if they are a kind of yet-undefined haecceity, produced by other haecceities, that produce changes in anything they intersect or interact with. It is not just that “sensory stimuli bypass logocentric intervention” which makes tripping so worth looking at, and within her discussion of these affects, Cichosz suggests that the state of attentiveness, in this case specifically referring to a mode of being that is less concerned with rationality, and rather, more concerned with living in a state of openness to sensations (Cichosz, 2014; 57), can allow for a change in how affects influence us. It is hard to say we are more susceptible to these produced affects, but we are differently susceptible, in a way that also relates to the changes in cognitive and neurological behaviour that coincides with, instigate, and are consequential to, tripping. A simple example of this might be with something like rain: in Deleuzoguattarian terms, we can refer to rain as a haecceity, a non-object, something that is not a person or an object but has the same ontological behaviour in many ways such as weather. We are affected by the rain, the appearance of this non-object does something to us, or at us, or with us, or through us. How the rain affects you is not an inherent property of the rain, as, for example, the experience of it raining outside whilst at home, or in a cafe, has a different way of changing or influencing an observer, compared to if that observer was stuck outside enduring the rain. In just the same way, if someone was tripping on acid at a rave in the countryside of England, that cursed, omnipresent drizzle may suddenly transform into something miraculous, a moment of ecstatic truth to borrow the term from Werner Herzog. The “affects” produced by the rain manifesting through our observation are undefined and unspecific until factored into the perceptual matrix of whatever is conscious enough to actually be aware of rain. 

These affects become relevant to discussions of political change and ethics, as Cichosz writes: “In short, attention to affect is implication in ethics because thinking about affect is another way of thinking about potential, and potential is a way of conceptualising change, not only that which is possible, or which we can imagine happening, but also that which is indeterminate and radically new. Change depends upon fostering, tending to, and strategic actualisation of the potential found in affect”. There is a clear parallel here between this attentive openness, and Adorno’s advocacy of de-objectification as a necessary unlearning for finding a solution to future revolutions, and future change. If, as is recognised by contemporary Ontology of music, we either compulsively or habitually objectify everything, as if to obsessively attempt to transform an untrustworthy potential or absence or motion, into something that can be more ‘reliably’ handled through empirical, phallogocentric enquiry. Within Cichosz’ study, the idea of reasoning acts as a means to interrupt, contain or capture this fleeting, unreasonable something, and claims that such rationalisation processes prevent the development or fostering of potential in order to create room for the new. 
This is grounded in the work of Brian Massumi, who identifies that the bodies “best defence” again the new, is habit, or the “acquired automatic self-regulation [that] encourages us to dampen affect’s potential by disregarding the singular contours of an arriving impulse; dismissing its potentially tortuous anomalies as functionally insignificant” (Massumi, 2002; xxxi; Cichosz, 2014; 58). Due to the irrationality of potential, change and newness are therefore prevented from prospering, as the aspects of potential which bear change are the very aspects which are jettisoned in the processes of reason and rationalism. We must smuggle newness into the mind like a bag of pills into a music festival.


## Raving-machines and desubjectification


Tripping, then, a phenomenon much associated with music, and indeed rave, within this framework becomes a kind of altered manner of experience, not just in the sense that is attached to drug culture, but in general; to trip is to experience differently, atypically (Cichosz, 2014; 55). In reference to other Deleuzoguattarian literature, rave can be understood as a matter of desire and the drive towards realising desires. In Tim Jordan’s “collective bodies” (1995), rave is presented as a desiring-machine that seeks to realise a desiring-production through a specific assemblage that contains within it a fully existing, although now specified, desire, in this case the desire for desubjectification.
 
Without stretching too far, this sought-after desubjectification is a trip, a differentiation, albeit temporary, in how one experiences a stretch of experience where the tripper becomes more open to the generation of new ideas, or newfound hope. Until now we have been building up to the idea that the listening-submission of attentiveness is a key to unlocking the door into the raving-desiring-machine. A rave is a situation set up, where ritualistic attentiveness, in the form of ritualised listening to music, leads to an experience held as emancipatory by the listeners. It seems that no matter what lies on the other side of using the raving-machine, whether it be desubjectification, whether it be a temporary undoing of the Freudian tragedy of motherly separation, whether it be mere escapism from anguish, death-drive, or being-unborn, unionised, anything, the door to this experience lies in the ritualistic inversion and subversion of phallogocentric ritualism. 
 
While many renowned authors have detailed, to an extraordinary degree, the pharmacological and neuroscientific effects of using drugs such as Ketamine or Ecstasy within rave culture, particularly in regard to technoshamanism and transcendental, euphoric dance-floors, it is only within the entanglement of post-Lacanian anti-psychiatry and sociology where the reasons why such a phenomenon is relevant to discourses of politics and liberation can be found. The metaphysical relationship between music, listening, tripping, and consequently, change, is profound. In asking what power “paying attention” has, the role of a scandalous listening, and in particular, the listening of music is uncovered. The anti-phallogocentrism of the Ontology of music, the enquiry of music, the use of music for tripping, the relationship between tripping and new ideas, makes a clear case for why music, and in particular, raving, has been of such nuisance to both academia, and the State, both presently and historically. In the territorial dialectic between the Governors and the Governed, the purpose of the establishment of molar and molecular lines, as manifesting as tabloid outrage or police interventionism, and the justice system, are quite clear, operating as blockades, barricades, trenches, blocking the work of the raving-desiring-machine. 
 
In some of the metaphors and figures used here, we find again an image that has been prominent in this discourse, the image of returning to the mother, of becoming-women, of arraigning phallogocentrism. Returning to one of the interests of this text overall, within Capitalist Realism, the idea of what it means to be revolutionary could, arguably, now regard tools for unlearning the biases and discriminations, to enable newness by being open to it. Whether in rave, or not, the role of listening itself is foregrounded in this revolutionary sense. Through Cichosz’ attentive listening, you allow stimuli to essentially ephemerally bypass the webs of positivistic, rational scrutiny and examination, that reach out and intercept experience or affects in a way that prevent new understandings and ideas prospering.
 
If a primary issue today is a lack of imagination, a lack of practiced ability to rearrange the components of the social, or even rearrange musical components for that matter, and a lack of hope for change as a result of that lack of imagination, then the uncovering of methods for re-cognising, and re-imagining things are of great value. Such attentiveness practices, such as those with rave culture, transform events or ritualised gatherings or communal activity into gateways to states of experience that can inculcate new thoughts or develop imaginative capacities. It is not to say rave can change the world, rather that there is, to Adorno’s delight, a lot of reason to reconsider the revolutionary potential of music, as a means of fostering change, and escaping the slow cancellation of the future.




